@@ -88,8 +88,13 @@ enum
 enum
 {
   DEVICE_TYPE_LOCAL = 0,
-  DEVICE_TYPE_NETWORK,
-  DEVICE_TYPE_N
+  DEVICE_TYPE_NETWORK
+};
+
+enum
+{
+  STANDARD_TAB = 0,
+  WARNING_TAB
 };
 
 typedef struct{
@@ -155,6 +160,7 @@ device_type_selection_changed_cb (GtkTreeSelection *selection,
   GtkTreeModel       *model;
   GtkTreeIter         iter;
   GtkWidget          *treeview = NULL;
+  GtkWidget          *notebook = NULL;
   GtkWidget          *widget;
   gchar              *device_type_name = NULL;
   gint                device_type_id = -1;
@@ -174,17 +180,30 @@ device_type_selection_changed_cb (GtkTreeSelection *selection,
       widget = (GtkWidget*)
         gtk_builder_get_object (pp->builder, "device-type-notebook");
 
-      if (pp->show_warning && device_type == DEVICE_TYPE_NETWORK)
-        gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 2);
-      else
-        gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), device_type);
+      gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), device_type);
 
       if (device_type == DEVICE_TYPE_LOCAL)
-        treeview = (GtkWidget*)
-          gtk_builder_get_object (pp->builder, "local-devices-treeview");
+        {
+          treeview = (GtkWidget*)
+            gtk_builder_get_object (pp->builder, "local-devices-treeview");
+          notebook = (GtkWidget*)
+            gtk_builder_get_object (pp->builder, "local-devices-notebook");
+        }
       else if (device_type == DEVICE_TYPE_NETWORK)
-        treeview = (GtkWidget*)
-          gtk_builder_get_object (pp->builder, "network-devices-treeview");
+        {
+          treeview = (GtkWidget*)
+            gtk_builder_get_object (pp->builder, "network-devices-treeview");
+          notebook = (GtkWidget*)
+            gtk_builder_get_object (pp->builder, "network-devices-notebook");
+        }
+
+      if (notebook)
+        {
+          if (pp->show_warning && device_type == DEVICE_TYPE_NETWORK)
+            gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), WARNING_TAB);
+          else
+            gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), STANDARD_TAB);
+        }
 
       widget = (GtkWidget*)
         gtk_builder_get_object (pp->builder, "new-printer-add-button");
@@ -574,6 +593,7 @@ DBus method \"GroupPhysicalDevices\" to group duplicates in device list.");
         gtk_builder_get_object (pp->builder, "spinner");
       gtk_spinner_stop (GTK_SPINNER (widget));
       gtk_widget_set_sensitive (widget, FALSE);
+      gtk_widget_hide (widget);
 
       if (pp->cancellable != NULL)
         {
@@ -609,8 +629,12 @@ devices_get (PpNewPrinterDialog *pp)
       if (pp->show_warning)
         {
           widget = (GtkWidget*)
-            gtk_builder_get_object (pp->builder, "device-type-notebook");
-          gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 2);
+            gtk_builder_get_object (pp->builder, "local-devices-notebook");
+          gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), WARNING_TAB);
+
+          widget = (GtkWidget*)
+            gtk_builder_get_object (pp->builder, "network-devices-notebook");
+          gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), WARNING_TAB);
         }
 
       in_include = g_variant_builder_new (G_VARIANT_TYPE ("as"));
@@ -630,6 +654,7 @@ devices_get (PpNewPrinterDialog *pp)
         gtk_builder_get_object (pp->builder, "spinner");
       gtk_spinner_start (GTK_SPINNER (widget));
       gtk_widget_set_sensitive (widget, TRUE);
+      gtk_widget_show (widget);
 
       pp->cancellable = g_cancellable_new ();
 
@@ -1139,6 +1164,8 @@ actualize_devices_list (PpNewPrinterDialog *pp)
   GtkTreeIter   iter;
   GtkWidget    *treeview;
   GtkWidget    *widget;
+  GtkWidget    *local_notebook;
+  GtkWidget    *network_notebook;
   gint          i;
   gint          device_type = -1;
 
@@ -1206,10 +1233,15 @@ actualize_devices_list (PpNewPrinterDialog *pp)
   widget = (GtkWidget*)
     gtk_builder_get_object (pp->builder, "device-type-notebook");
 
-  if (pp->show_warning && device_type == DEVICE_TYPE_NETWORK)
-    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 2);
-  else
-    gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), device_type);
+  local_notebook = (GtkWidget*)
+    gtk_builder_get_object (pp->builder, "local-devices-notebook");
+
+  network_notebook = (GtkWidget*)
+    gtk_builder_get_object (pp->builder, "network-devices-notebook");
+
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (network_notebook), pp->show_warning ? WARNING_TAB : STANDARD_TAB);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (local_notebook), STANDARD_TAB);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), device_type);
 
   g_object_unref (network_store);
   g_object_unref (local_store);
@@ -1264,7 +1296,15 @@ Network printer detection needs services mdns, ipp, ipp-client \
 and samba-client enabled on firewall."));
 
       warning_textview = (GtkTextView*)
-        gtk_builder_get_object (pp->builder, "warning-textview");
+        gtk_builder_get_object (pp->builder, "local-warning");
+      text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (warning_textview));
+
+      gtk_text_buffer_set_text (text_buffer, "", 0);
+      gtk_text_buffer_get_iter_at_offset (text_buffer, &text_iter, 0);
+      gtk_text_buffer_insert (text_buffer, &text_iter, pp->warning, -1);
+
+      warning_textview = (GtkTextView*)
+        gtk_builder_get_object (pp->builder, "network-warning");
       text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (warning_textview));
 
       gtk_text_buffer_set_text (text_buffer, "", 0);
@@ -1626,7 +1666,9 @@ new_printer_add_button_cb (GtkButton *button,
           DBusGProxy *proxy;
           GError     *error = NULL;
           char       *ret_error = NULL;
-          char       *locale = NULL;
+          ppd_file_t  *ppd_file = NULL;
+          gchar      **value = NULL;
+          const gchar *paper_size;
 
           ppd_file_name = cupsGetPPD (pp->devices[device_id].display_name);
 
@@ -1665,75 +1707,60 @@ new_printer_add_button_cb (GtkButton *button,
 
 
               /* Set default PaperSize according to the locale */
-              locale = setlocale (LC_PAPER, NULL);
-              if (locale == NULL)
-                locale = setlocale (LC_MESSAGES, NULL);
+              paper_size = gtk_paper_size_get_default ();
+              if (g_str_equal (paper_size, GTK_PAPER_NAME_LETTER))
+                paper_size = "Letter";
+              else
+                paper_size = "A4";
 
-              if (locale)
+              if (ppd_file_name)
                 {
-                  ppd_file_t  *ppd_file = NULL;
-                  gchar      **value = NULL;
-                  gchar       *paper_size;
-
-                  /* CLDR 2.0 alpha
-                   * http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/territory_language_information.html
-                   */
-                  if (g_regex_match_simple ("[^_.@]{2,3}_(BZ|CA|CL|CO|CR|GT|MX|NI|PA|PH|PR|SV|US|VE)",
-                                            locale, G_REGEX_ANCHORED, G_REGEX_MATCH_ANCHORED))
-                    paper_size = g_strdup ("Letter");
-                  else
-                    paper_size = g_strdup ("A4");
-
-                  if (ppd_file_name)
+                  ppd_file = ppdOpenFile (ppd_file_name);
+                  if (ppd_file)
                     {
-                      ppd_file = ppdOpenFile (ppd_file_name);
-                      if (ppd_file)
-                        {
-                          ppdMarkDefaults (ppd_file);
-                          for (i = 0; i < ppd_file->num_groups; i++)
-                            for (j = 0; j < ppd_file->groups[i].num_options; j++)
-                              if (g_strcmp0 ("PageSize", ppd_file->groups[i].options[j].keyword) == 0)
+                      ppdMarkDefaults (ppd_file);
+                      for (i = 0; i < ppd_file->num_groups; i++)
+                        for (j = 0; j < ppd_file->groups[i].num_options; j++)
+                          if (g_strcmp0 ("PageSize", ppd_file->groups[i].options[j].keyword) == 0)
+                            {
+                              for (k = 0; k < ppd_file->groups[i].options[j].num_choices; k++)
                                 {
-                                  for (k = 0; k < ppd_file->groups[i].options[j].num_choices; k++)
+                                  if (g_ascii_strncasecmp (paper_size,
+                                                           ppd_file->groups[i].options[j].choices[k].choice,
+                                                           strlen (paper_size)) == 0 &&
+                                      !ppd_file->groups[i].options[j].choices[k].marked)
                                     {
-                                      if (g_ascii_strncasecmp (paper_size,
-                                                               ppd_file->groups[i].options[j].choices[k].choice,
-                                                               strlen (paper_size)) == 0 &&
-                                          !ppd_file->groups[i].options[j].choices[k].marked)
-                                        {
-                                          value = g_new0 (gchar *, 2);
-                                          value[0] = g_strdup (ppd_file->groups[i].options[j].choices[k].choice);
-                                          break;
-                                        }
+                                      value = g_new0 (gchar *, 2);
+                                      value[0] = g_strdup (ppd_file->groups[i].options[j].choices[k].choice);
+                                      break;
                                     }
-                                  break;
                                 }
-                          ppdClose (ppd_file);
-                        }
+                              break;
+                            }
+                      ppdClose (ppd_file);
                     }
+                }
 
-                  if (value)
+              if (value)
+                {
+                  dbus_g_proxy_call (proxy, "PrinterAddOptionDefault", &error,
+                                     G_TYPE_STRING, pp->devices[device_id].display_name,
+                                     G_TYPE_STRING, "PageSize",
+                                     G_TYPE_STRV, value,
+                                     G_TYPE_INVALID,
+                                     G_TYPE_STRING, &ret_error,
+                                     G_TYPE_INVALID);
+
+                  if (error)
                     {
-                      dbus_g_proxy_call (proxy, "PrinterAddOptionDefault", &error,
-                                         G_TYPE_STRING, pp->devices[device_id].display_name,
-                                         G_TYPE_STRING, "PageSize-default",
-                                         G_TYPE_STRV, value,
-                                         G_TYPE_INVALID,
-                                         G_TYPE_STRING, &ret_error,
-                                         G_TYPE_INVALID);
-
-                      if (error)
-                        {
-                          g_warning ("%s", error->message);
-                          g_clear_error (&error);
-                        }
-
-                      if (ret_error && ret_error[0] != '\0')
-                        g_warning ("%s", ret_error);
-
-                      g_strfreev (value);
+                      g_warning ("%s", error->message);
+                      g_clear_error (&error);
                     }
-                  g_free (paper_size);
+
+                  if (ret_error && ret_error[0] != '\0')
+                    g_warning ("%s", ret_error);
+
+                  g_strfreev (value);
                 }
               g_object_unref (proxy);
             }
