@@ -40,10 +40,19 @@ G_DEFINE_DYNAMIC_TYPE (CcWacomPanel, cc_wacom_panel, CC_TYPE_PANEL)
 struct _CcWacomPanelPrivate
 {
 	GtkBuilder  *builder;
+	GtkWidget   *notebook;
 	GSettings   *wacom_settings;
 	GSettings   *stylus_settings;
 	GSettings   *eraser_settings;
 	/* The UI doesn't support cursor/pad at the moment */
+	GdkDeviceManager *manager;
+	guint             device_added_id;
+	guint             device_removed_id;
+};
+
+enum {
+	PLUG_IN_PAGE,
+	WACOM_PAGE
 };
 
 /* Button combo box storage columns */
@@ -370,6 +379,13 @@ cc_wacom_panel_dispose (GObject *object)
 		priv->eraser_settings = NULL;
 	}
 
+	if (priv->manager)
+	{
+		g_signal_handler_disconnect (priv->manager, priv->device_added_id);
+		g_signal_handler_disconnect (priv->manager, priv->device_removed_id);
+		priv->manager = NULL;
+	}
+
 	G_OBJECT_CLASS (cc_wacom_panel_parent_class)->dispose (object);
 }
 
@@ -397,16 +413,85 @@ cc_wacom_panel_class_finalize (CcWacomPanelClass *klass)
 {
 }
 
+static gboolean
+has_wacom_tablet (CcWacomPanel *self)
+{
+	GList *list, *l;
+	gboolean retval;
+
+	retval = FALSE;
+	list = gdk_device_manager_list_devices (self->priv->manager,
+						GDK_DEVICE_TYPE_SLAVE);
+	for (l = list; l != NULL; l = l->next)
+	{
+		GdkDevice *device = l->data;
+		GdkInputSource source;
+
+		source = gdk_device_get_source (device);
+		if (source == GDK_SOURCE_PEN ||
+		    source == GDK_SOURCE_ERASER)
+		{
+			retval = TRUE;
+			break;
+		}
+	}
+	g_list_free (list);
+	return retval;
+}
+
+static void
+update_current_page (CcWacomPanel *self)
+{
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (self->priv->notebook),
+				       has_wacom_tablet (self) ? WACOM_PAGE : PLUG_IN_PAGE);
+}
+
+static void
+device_changed_cb (GdkDeviceManager *manager,
+		   GdkDevice        *device,
+		   CcWacomPanel     *self)
+{
+	update_current_page (self);
+}
+
+static gboolean
+link_activated (GtkLinkButton *button,
+		CcWacomPanel  *self)
+{
+	CcShell *shell;
+	GError *error = NULL;
+
+	shell = cc_panel_get_shell (CC_PANEL (self));
+	if (cc_shell_set_active_panel_from_id (shell, "bluetooth", NULL, &error) == FALSE)
+	{
+		g_warning ("Failed to activate Bluetooth panel: %s", error->message);
+		g_error_free (error);
+	}
+	return TRUE;
+}
+
+static void
+enbiggen_label (GtkLabel *label)
+{
+	const char *str;
+	char *new_str;
+
+	str = gtk_label_get_text (label);
+	new_str = g_strdup_printf ("<big>%s</big>", str);
+	gtk_label_set_markup (label, new_str);
+	g_free (new_str);
+}
+
 static void
 cc_wacom_panel_init (CcWacomPanel *self)
 {
 	CcWacomPanelPrivate *priv;
-	GtkWidget *grid;
+	GtkWidget *notebook;
 	GError *error = NULL;
 	GtkComboBox *combo;
 	GtkSwitch *sw;
 	char *objects[] = {
-		"main-grid",
+		"main-notebook",
 		"liststore-tabletmode",
 		"liststore-buttons",
 		"adjustment-tip-feel",
@@ -430,9 +515,11 @@ cc_wacom_panel_init (CcWacomPanel *self)
 		return;
 	}
 
-	grid = WID ("main-grid");
-	gtk_container_add (GTK_CONTAINER (self), grid);
-	gtk_container_set_border_width (GTK_CONTAINER (grid), 24);
+	notebook = WID ("main-notebook");
+	gtk_container_add (GTK_CONTAINER (self), notebook);
+	gtk_widget_set_vexpand (GTK_WIDGET (notebook), TRUE);
+	gtk_container_set_border_width (GTK_CONTAINER (notebook), 24);
+	priv->notebook = notebook;
 
 	priv->wacom_settings  = g_settings_new (WACOM_SCHEMA);
 	priv->stylus_settings = g_settings_new (WACOM_STYLUS_SCHEMA);
@@ -471,6 +558,16 @@ cc_wacom_panel_init (CcWacomPanel *self)
 
 	gtk_image_set_from_file (GTK_IMAGE (WID ("image-tablet")), PIXMAP_DIR "/wacom-tablet.svg");
 	gtk_image_set_from_file (GTK_IMAGE (WID ("image-stylus")), PIXMAP_DIR "/wacom-stylus.svg");
+
+	enbiggen_label (GTK_LABEL (WID ("advice-label1")));
+	priv->manager = gdk_display_get_device_manager (gdk_display_get_default ());
+	priv->device_added_id = g_signal_connect (G_OBJECT (priv->manager), "device-added",
+						  G_CALLBACK (device_changed_cb), self);
+	priv->device_removed_id = g_signal_connect (G_OBJECT (priv->manager), "device-removed",
+						    G_CALLBACK (device_changed_cb), self);
+	g_signal_connect (G_OBJECT (WID ("linkbutton")), "activate-link",
+			  G_CALLBACK (link_activated), self);
+	update_current_page (self);
 }
 
 void
